-- main.lua
function love.load(arg)
  -- declare shorthand framework names
  lg = love.graphics
  li = love.image
  la = love.audio
  lm = love.mouse
  lk = love.keyboard
  lt = love.timer
  le = love.event
  ls = love.system
  lw = love.window
  lf = love.filesystem


  lg.setDefaultFilter('nearest', 'nearest')

  -- import third-party libraries
  require 'lib.autobatch'
  Gamestate = require 'lib.gamestate'
  Class = require 'lib.class'
  Signal = require 'lib.signal'
  Timer = require 'lib.timer'
  Vector = require 'lib.vector'
  Camera = require 'lib.camera'
  --Bitser = require 'lib.bitser'
  Bump = require 'lib.bump'
  FOV = require 'lib.ppfov'
  --FOV = require 'lib.rsfov'
  JSON = require 'lib.json'
  ROT = require 'lib.rotLove'

  -- load modules
  local colors = require 'modules.setup.colors'
  local settings = require 'modules.setup.settings'

  local modules = {
    'setup.fonts',
    'setup.spritesheets',
    'setup.quads'
  }
  for _,v in pairs(modules) do
    require ('modules.' .. v)
  end

  -- set up states
  local states = {
    'titlescreen',
    'mainmenu',
    'game',
    'options',
    'wingame'
  }
  for _,v in pairs(states) do
    require ('states.' .. v)
  end

  -- user settings
  local settingsfilename = 'settings.json'
  USERSETTINGS = {
    screenEffects = false
  }
  if lf.exists(settingsfilename) then
    local str = lf.read(settingsfilename)
    local settings = JSON.decode(str)
    for k,v in pairs(settings) do
      USERSETTINGS[k] = v
    end
  else
    lf.write(settingsfilename, JSON.encode(USERSETTINGS))
  end

  -- window/scaling setup:
  local w, h, flags = lw.getMode()
  -- lw.setMode(
  --   settings.pxWidth * settings.scale,
  --   settings.pxHeight * settings.scale,
  --   flags
  -- )
  Gflags = flags

  w, h, flags = lw.getMode()
  GscaleX, GscaleY = w/settings.pxWidth, h/settings.pxHeight

  -- seed the RNG and start the game:
  ROT.RNG:seed()
  lg.setBackgroundColor(colors.black)
  Gamestate.registerEvents()
  Gamestate.switch(TitleScreen)

end

function love.update(dt)
  Timer.update(dt)
end

function love.draw()

end

function love.keypressed(key)
  local settings = require 'modules.setup.settings'
  if key == 'f4' and (lk.isDown('ralt') or lk.isDown('lalt')) then
    le.quit()
  elseif key == 'p' then
    local screenshot = lg.newScreenshot()
    screenshot:encode('png', os.time() .. '.png')
  elseif key == 'f1' or key == 'f11' then
    local fullscreen, fstype = lw.getFullscreen()
    local flags = Gflags
    if fullscreen then
      local w, h = settings.pxWidth * settings.scale, settings.pxHeight * settings.scale
      flags.fullscreen = false
      flags.borderless = false
      lw.setMode(w, h, flags)
      w, h, flags = lw.getMode()
      GscaleX, GscaleY = w/settings.pxWidth, h/settings.pxHeight
    else
      local w, h = lw.getDesktopDimensions()
      flags.fullscreen = true
      flags.borderless = true
      lw.setMode(w, h, flags)

      local sx, sy = w/settings.pxWidth, h/settings.pxHeight
      GscaleX, GscaleY = math.min(sx, sy), math.min(sx, sy)
    end
    Signal.emit('resize')
  end
end

function love.mousepressed(x, y, button, istouch)

end

function love.resize(w, h)
  local settings = require 'modules.setup.settings'
  love.window.setMode(w, h, Gflags)
  local sx, sy = w/settings.pxWidth, h/settings.pxHeight
  GscaleX, GscaleY = math.min(sx, sy), math.min(sx, sy)
  Signal.emit('resize')
end
