local colors = require 'modules.setup.colors'
local settings = require 'modules.setup.settings'
local utils = require 'modules.setup.utils'

local enemylist = {}

enemylist.default = {}
-----------------------------------------------------------
-- fauna
-----------------------------------------------------------
enemylist.rat = {
  name = 'Rat',
  enemytype = 'rat',
  quadname = 'rat',
  fg = colors.lightblue,
  ac = 15,
  hd = {1,8,1},
  tohit = {1,20,4},
  damage = {1,4,0},
  droplist = {
    cheese = 50,
    dagger = 10,
    tunic = 10,
    cloak = 10,
    glasses = 10,
    key = 10
  }
}
enemylist.bat = {
  name = 'Bat',
  enemytype = 'bat',
  quadname = 'bat',
  fg = colors.purple,
  ac = 15,
  hd = {1,8,2},
  tohit = {1,20,4},
  damage = {1,2,0},
  droplist = {
    apple = 50,
    dagger = 10,
    leatherhelmet = 10,
    wizardhat = 10,
    gold = 10,
    key = 10
  }
}
enemylist.centipede = {
  name = 'Centipede',
  enemytype = 'centipede',
  quadname = 'centipede',
  fg = colors.red,
  ac = 14,
  hd = {1,8,2},
  tohit = {1,20,1},
  damage = {1,3,0},
  droplist = {
    cheese = 50,
    sword = 10,
    leatherhelmet = 10,
    wizardhat = 10,
    smallpotion = 10,
    glasses = 10
  }
}
enemylist.spider = {
  name = 'Spider',
  enemytype = 'spider',
  quadname = 'spider',
  fg = colors.lightbrown,
  ac = 14,
  hd = {4,8,4},
  tohit = {1,20,4},
  damage = {1,8,4},
  droplist = {
    beer = 50,
    spear = 10,
    battleaxe = 10,
    handaxe = 10,
    staff = 10,
    mediumpotion = 10
  }
}
enemylist.scorpion = {
  name = 'Scorpion',
  enemytype = 'scorpion',
  quadname = 'scorpion',
  fg = colors.red,
  ac = 16,
  hd = {5,8,10},
  tohit = {1,20,6},
  damage = {2,4,3},
  droplist = {
    spear = 50,
    club = 10,
    buckler = 10,
    wizardhat = 10,
    smallpotion = 10,
    mediumpotion = 10
  }
}
enemylist.snail = {
  name = 'Snail',
  enemytype = 'snail',
  quadname = 'snail',
  fg = colors.darkblue,
  ac = 14,
  hd = {1,4,2},
  tohit = {1,20,2},
  damage = {1,2,0},
  droplist = {
    apple = 33,
    cheese = 33,
    mushroom = 34
  }
}
enemylist.snake = {
  name = 'Snake',
  enemytype = 'snake',
  quadname = 'snake',
  fg = colors.darkgreen,
  ac = 15,
  hd = {3,8,6},
  tohit = {1,20,4},
  damage = {1,4,0},
  droplist = {
    smallpotion = 50,
    hammer = 10,
    buckler = 10,
    metalhelmet = 10,
    mushroom = 10,
    mediumpotion = 10
  }
}
enemylist.fox = {
  name = 'Fox',
  enemytype = 'fox',
  quadname = 'fox',
  fg = colors.orange,
  ac = 14,
  hd = {2,8,4},
  tohit = {1,20,3},
  damage = {1,6,1},
  droplist = {
    drumstick = 50,
    dagger = 10,
    staff = 10,
    metalhelmet = 10,
    mushroom = 10,
    spear = 10
  }
}
enemylist.panther = {
  name = 'Panther',
  enemytype = 'panther',
  quadname = 'panther',
  fg = colors.darkbrown,
  ac = 13,
  hd = {3,8,6},
  tohit = {1,20,6},
  damage = {2,6,4},
  droplist = {
    drumstick = 50,
    dagger = 10,
    staff = 10,
    metalhelmet = 10,
    mushroom = 10,
    spear = 10
  }
}
enemylist.bear = {
  name = 'Bear',
  enemytype = 'bear',
  quadname = 'bear',
  fg = colors.darkbrown,
  ac = 15,
  hd = {6,8,24},
  tohit = {1,20,11},
  damage = {1,8,8},
  droplist = {
    towershield = 33,
    metalarmor = 33,
    largepotion = 33
  }
}
enemylist.wyvern = {
  name = 'Wyvern',
  enemytype = 'wyvern',
  quadname = 'wyvern',
  fg = colors.lightgreen,
  ac = 18,
  hd = {7,12,14},
  tohit = {1,20,10},
  damage = {2,6,8},
  droplist = {
    towershield = 33,
    metalarmor = 33,
    largepotion = 33
  }
}
enemylist.dragon = {
  name = 'Dragon',
  enemytype = 'dragon',
  quadname = 'dragon',
  fg = colors.lightgreen,
  ac = 21,
  hd = {13,12,39},
  tohit = {1,20,20},
  damage = {2,6,7},
  droplist = {
    battleaxe = 25,
    towershield = 25,
    metalarmor = 25,
    largepotion = 25
  }
}
enemylist.unicorn = {
  name = 'Unicorn',
  enemytype = 'unicorn',
  quadname = 'unicorn',
  fg = colors.pink,
  ac = 13,
  hd = {3,8,6},
  tohit = {1,20,-1},
  damage = {1,6,1},
  droplist = {
    crown = 100
  }
}

-----------------------------------------------------------
-- trollkind
-----------------------------------------------------------
enemylist.goblin = {
  name = 'Goblin',
  enemytype = 'goblin',
  quadname = 'goblin',
  fg = colors.lightgreen,
  ac = 15,
  hd = {1,8,1},
  tohit = {1,20,2},
  damage = {1,6,0},
  droplist = {
    sword = 10,
    dagger = 10,
    club = 10,
    metalhelmet = 10,
    leatherhelmet = 10,
    wizardhat = 10,
    buckler = 10,
    key = 10,
    gold = 10,
    beer = 10
  }
}
enemylist.troll = {
  name = 'Troll',
  enemytype = 'troll',
  quadname = 'troll',
  fg = colors.lightgreen,
  ac = 16,
  hd = {6,8,36},
  tohit = {1,20,9},
  damage = {1,6,6},
  droplist = {
    spear = 15,
    axe = 15,
    glasses = 15,
    tunic = 15,
    cloak = 10,
    sword = 10,
    staff = 10,
    apple = 5,
    beer = 5
  }
}
enemylist.cyclops = {
  name = 'Cylcops',
  enemytype = 'cyclops',
  quadname = 'cyclops',
  fg = colors.darkgreen,
  ac = 16,
  hd = {4,8,11},
  tohit = {1,20,8},
  damage = {2,8,7},
  droplist = {
    club = 15,
    hammer = 15,
    leatherhelmet = 15,
    metalarmor = 15,
    metalhelmet = 10,
    sword = 10,
    staff = 10,
    drumstick = 5,
    beer = 5
  }
}
enemylist.orc = {
  name = 'Orc',
  enemytype = 'orc',
  quadname = 'orc',
  fg = colors.darkgreen,
  ac = 13,
  hd = {1,8,1},
  tohit = {1,20,4},
  damage = {1,6,3},
  droplist = {
    club = 15,
    hammer = 15,
    leatherhelmet = 15,
    metalarmor = 15,
    metalhelmet = 10,
    buckler = 10,
    towershield = 10,
    drumstick = 5,
    beer = 5
  }
}

-----------------------------------------------------------
-- the unliving
-----------------------------------------------------------
enemylist.zombie = {
  name = 'Zombie',
  enemytype = 'zombie',
  quadname = 'zombie',
  fg = colors.darkgreen,
  ac = 11,
  hd = {2,12,3},
  tohit = {1,20,2},
  damage = {1,6,1},
  droplist = {
    club = 15,
    hammer = 15,
    leatherhelmet = 15,
    metalarmor = 15,
    metalhelmet = 10,
    buckler = 10,
    towershield = 10,
    drumstick = 5,
    beer = 5
  }
}
enemylist.hand = {
  name = 'Hand',
  enemytype = 'hand',
  quadname = 'hand',
  fg = colors.lightgreen,
  ac = 15,
  hd = {1,6,1},
  tohit = {1,20,4},
  damage = {1,4,0},
  droplist = {
    gold = 25,
    apple = 25,
    cheese = 25,
    mushroom = 25
  }
}
enemylist.skeleton = {
  name = 'Skeleton',
  enemytype = 'skeleton',
  quadname = 'skeleton',
  fg = colors.white,
  ac = 15,
  hd = {1,12,0},
  tohit = {1,20,1},
  damage = {1,6,1},
  droplist = {
    sword = 10,
    spear = 10,
    dagger = 5,
    apple = 25,
    cheese = 25,
    mushroom = 25
  }
}
enemylist.skeletonknight = {
  name = 'Skeleton Knight',
  enemytype = 'skeletonknight',
  quadname = 'skeleton',
  fg = colors.white,
  ac = 16,
  hd = {2,12,0},
  tohit = {1,20,2},
  damage = {2,6,0},
  droplist = {
    sword = 10,
    spear = 10,
    dagger = 5,
    apple = 25,
    cheese = 25,
    mushroom = 25
  }
}
enemylist.lich = {
  name = 'Lich',
  enemytype = 'lich',
  quadname = 'lich',
  fg = colors.gray,
  ac = 15,
  hd = {2,12,3},
  tohit = {1,20,2},
  damage = {1,6,1},
  droplist = {
    smallpotion = 80,
    mediumpotion = 15,
    largepotion = 5
  }
}
enemylist.ghost = {
  name = 'Ghost',
  enemytype = 'ghost',
  quadname = 'ghost',
  fg = colors.gray,
  ac = 14,
  hd = {2,12,0},
  tohit = {1,20,2},
  damage = {1,6,1},
  droplist = {
    wizardhat = 50,
    cloak = 50
  }
}
enemylist.wisp = {
  name = 'Wisp',
  enemytype = 'wisp',
  quadname = 'wisp',
  fg = colors.orange,
  ac = 11,
  hd = {1,12,2},
  tohit = {1,20,2},
  damage = {1,4,0},
  droplist = {
    sword = 10,
    spear = 10,
    dagger = 5,
    apple = 25,
    cheese = 25,
    mushroom = 25
  }
}

-----------------------------------------------------------
-- creatures
-----------------------------------------------------------
enemylist.ooze = {
  name = 'Ooze',
  enemytype = 'ooze',
  quadname = 'ooze',
  fg = colors.lightgreen,
  ac = 3,
  hd = {4,12,32},
  tohit = {1,20,1},
  damage = {2,6,0},
  droplist = {
    metalarmor = 25,
    towershield = 25,
    battleaxe = 25,
    heavyshield = 25
  }
}
enemylist.tentacles = {
  name = 'Tentacles',
  enemytype = 'tentacles',
  quadname = 'tentacles',
  fg = colors.pink,
  ac = 20,
  hd = {8,8,24},
  tohit = {1,20,11},
  damage = {2,6,5},
  droplist = {
    metalarmor = 20,
    towershield = 20,
    battleaxe = 20,
    heavyshield = 20,
    mediumpotion = 20,
    largepotion = 5
  }
}
enemylist.imp = {
  name = 'Imp',
  enemytype = 'imp',
  quadname = 'imp',
  fg = colors.rust,
  ac = 15,
  hd = {1,8,1},
  tohit = {1,20,2},
  damage = {1,6,1},
  droplist = {
    dagger = 25,
    sword = 25,
    beer = 25,
    drumstick = 20,
    mediumpotion = 5
  }
}
enemylist.fireimp = {
  name = 'Fire Imp',
  enemytype = 'fireimp',
  quadname = 'fireimp',
  fg = colors.red,
  ac = 16,
  hd = {2,8,3},
  tohit = {1,20,2},
  damage = {1,6,2},
  droplist = {
    spear = 25,
    tunic = 25,
    beer = 25,
    drumstick = 20,
    mediumpotion = 5
  }
}
enemylist.mimic = {
  name = 'Mimic',
  enemytype = 'mimic',
  quadname = 'mimic',
  fg = colors.lightbrown,
  ac = 14,
  hd = {2,12,3},
  tohit = {1,20,2},
  damage = {1,6,1},
  droplist = {
    gold = 100
  }
}
enemylist.robot = {
  name = 'Robot',
  enemytype = 'robot',
  quadname = 'robot',
  fg = colors.gray,
  ac = 16,
  hd = {4,12,3},
  tohit = {1,20,2},
  damage = {1,6,1},
  droplist = {
    metalhelmet = 25,
    towershield = 25,
    heavyshield = 25,
    mediumpotion = 15,
    largepotion = 10
  }
}
enemylist.golem = {
  name = 'Golem',
  enemytype = 'golem',
  quadname = 'golem',
  fg = colors.mediumbrown,
  ac = 16,
  hd = {4,12,0},
  tohit = {1,20,2},
  damage = {1,6,1},
  droplist = {
    metalhelmet = 25,
    towershield = 25,
    heavyshield = 25,
    mediumpotion = 15,
    largepotion = 10
  }
}

return enemylist
