local colors = require 'modules.setup.colors'
local settings = require 'modules.setup.settings'
local utils = require 'modules.setup.utils'

local itemlist = {}

itemlist.nothing = {
  name = 'Nothing',
  quadname = 'unknown',
  itemtype = 'nothing',
  fg = colors.white
}

itemlist.gold = {
  name = 'Gold',
  quadname = 'gold',
  itemtype = 'gold',
  fg = colors.yellow,
  value = 1,
  autopickup = true,
  postInit = function(self)
    self.value = love.math.random(1,5)
  end
}

itemlist.key = {
  name = 'Key',
  quadname = 'key',
  itemtype = 'key',
  fg = colors.gray,
  value = 1,
  autopickup = true
}
-----------------------------------------------------------
-- CONSUMABLES
-----------------------------------------------------------
-----------------------------------------------------------
-- food
-----------------------------------------------------------
itemlist.cheese = {
  name = 'Cheese',
  quadname = 'cheese',
  itemtype = 'cheese',
  isConsumable = true,
  isStackable = true,
  isFood = true,
  fg = colors.yellow,
  description = 'Restores a small amount of health.',
  onUse = function(self, player)
    local amt = love.math.random(1,8)
    if self.bonus then amt = amt + self.bonus end
    return player:heal(amt)
  end
}
itemlist.apple = {
  name = 'Apple',
  quadname = 'apple',
  itemtype = 'apple',
  isConsumable = true,
  isStackable = true,
  isFood = true,
  fg = colors.red,
  description = 'Restores a small amount of health.',
  onUse = function(self, player)
    local amt = love.math.random(1,8)
    if self.bonus then amt = amt + self.bonus end
    return player:heal(amt)
  end
}
itemlist.drumstick = {
  name = 'Drumstick',
  quadname = 'drumstick',
  itemtype = 'drumstick',
  isConsumable = true,
  isStackable = true,
  isFood = true,
  fg = colors.lightbrown,
  description = 'Restores a moderate amount of health.',
  onUse = function(self, player)
    local amt = love.math.random(2,8)
    if self.bonus then amt = amt + self.bonus end
    return player:heal(amt)
  end
}
itemlist.beer = {
  name = 'Beer',
  quadname = 'beer',
  itemtype = 'beer',
  isConsumable = true,
  isStackable = true,
  isFood = true,
  fg = colors.yellow,
  description = 'Restores a moderate amount of health.',
  onUse = function(self, player)
    local amt = love.math.random(2,8)
    if self.bonus then amt = amt + self.bonus end
    return player:heal(amt)
  end
}
itemlist.mushroom = {
  name = 'Mushroom',
  quadname = 'mushroom',
  itemtype = 'mushroom',
  isConsumable = true,
  isStackable = true,
  isFood = true,
  fg = colors.red,
  description = 'Restores a small amount of health.',
  onUse = function(self, player)
    local amt = love.math.random(1,8)
    if self.bonus then amt = amt + self.bonus end
    return player:heal(amt)
  end
}
itemlist.smallpotion = {
  name = 'Small Potion',
  quadname = 'potionsmall',
  itemtype = 'smallpotion',
  isConsumable = true,
  isStackable = true,
  isFood = true,
  fg = colors.pink,
  description = 'Restores 50% of max health.',
  onUse = function(self, player)
    local amt = math.ceil(player.maxhp / 2)
    return player:heal(amt)
  end
}
itemlist.mediumpotion = {
  name = 'Medium Potion',
  quadname = 'potionmedium',
  itemtype = 'mediumpotion',
  isConsumable = true,
  isStackable = true,
  isFood = true,
  fg = colors.pink,
  description = 'Restores 75% of max health.',
  onUse = function(self, player)
    local amt = math.ceil(player.maxhp * .75)
    return player:heal(amt)
  end
}
itemlist.largepotion = {
  name = 'Large Potion',
  quadname = 'potionlarge',
  itemtype = 'largepotion',
  isConsumable = true,
  isStackable = true,
  isFood = true,
  fg = colors.pink,
  description = 'Restores 100% of max health.',
  onUse = function(self, player)
    local amt = player.maxhp
    return player:heal(amt)
  end
}
-----------------------------------------------------------
-- EQUIPMENT
-----------------------------------------------------------
-----------------------------------------------------------
-- Weapons
-----------------------------------------------------------
itemlist.dagger = {
  name = 'Dagger',
  quadname = 'dagger',
  itemtype = 'dagger',
  isEquipment = true,
  fg = colors.gray,
  slot = 'hand',
  damage = {1,4,0}
}
itemlist.sword = {
  name = 'Sword',
  quadname = 'sword',
  itemtype = 'sword',
  isEquipment = true,
  fg = colors.gray,
  slot = 'hand',
  damage = {1,6,0}
}
itemlist.handaxe = {
  name = 'Handaxe',
  quadname = 'axe',
  itemtype = 'handaxe',
  isEquipment = true,
  fg = colors.gray,
  slot = 'hand',
  damage = {1,4,0}
}
itemlist.battleaxe = {
  name = 'Battleaxe',
  quadname = 'axe',
  itemtype = 'battleaxe',
  isEquipment = true,
  fg = colors.gray,
  slot = 'hand',
  damage = {1,8,0}
}
itemlist.spear = {
  name = 'Spear',
  quadname = 'spear',
  itemtype = 'spear',
  isEquipment = true,
  fg = colors.lightblue,
  slot = 'hand',
  damage = {1,6,0}
}
itemlist.staff = {
  name = 'Staff',
  quadname = 'staff',
  itemtype = 'staff',
  isEquipment = true,
  fg = colors.mediumbrown,
  slot = 'hand',
  damage = {1,6,0}
}
itemlist.club = {
  name = 'Club',
  quadname = 'club',
  itemtype = 'club',
  isEquipment = true,
  fg = colors.brown,
  slot = 'hand',
  damage = {1,6,0}
}
itemlist.hammer = {
  name = 'Hammer',
  quadname = 'hammer',
  itemtype = 'hammer',
  isEquipment = true,
  fg = colors.mediumbrown,
  slot = 'hand',
  damage = {1,8,0}
}
-----------------------------------------------------------
-- shields
-----------------------------------------------------------
itemlist.buckler = {
  name = 'Buckler',
  quadname = 'buckler',
  itemtype = 'buckler',
  isEquipment = true,
  fg = colors.brown,
  slot = 'offhand',
  ac = 1
}
itemlist.heavyshield = {
  name = 'Heavy Shield',
  quadname = 'buckler',
  itemtype = 'heavyshield',
  isEquipment = true,
  fg = colors.brown,
  slot = 'offhand',
  ac = 2
}
itemlist.towershield = {
  name = 'Tower Shield',
  quadname = 'towershield',
  itemtype = 'towershield',
  isEquipment = true,
  fg = colors.mediumbrown,
  slot = 'offhand',
  ac = 4
}
-----------------------------------------------------------
-- head slot items
-----------------------------------------------------------
itemlist.leatherhelmet = {
  name = 'Leather Hat',
  quadname = 'leatherhelmet',
  itemtype = 'leatherhelmet',
  isEquipment = true,
  fg = colors.mediumbrown,
  slot = 'head',
  ac = 1
}
itemlist.metalhelmet = {
  name = 'Helmet',
  quadname = 'metalhelmet',
  itemtype = 'metalhelmet',
  isEquipment = true,
  fg = colors.gray,
  slot = 'head',
  ac = 2
}
itemlist.wizardhat = {
  name = 'Wizard Hat',
  quadname = 'wizardhat',
  itemtype = 'wizardhat',
  isEquipment = true,
  fg = colors.purple,
  slot = 'head',
  ac = 1
}
itemlist.crown = {
  name = 'Crown',
  quadname = 'crown',
  itemtype = 'crown',
  isEquipment = true,
  fg = colors.yellow,
  slot = 'head',
  ac = 1
}
itemlist.glasses = {
  name = 'Glasses',
  quadname = 'glasses',
  itemtype = 'glasses',
  isEquipment = true,
  fg = colors.lightblue,
  slot = 'head',
  ac = 1
}
-----------------------------------------------------------
-- body slot items
-----------------------------------------------------------
itemlist.tunic = {
  name = 'Tunic',
  quadname = 'tunic',
  itemtype = 'tunic',
  isEquipment = true,
  fg = colors.darkblue,
  slot = 'body',
  ac = 1
}
itemlist.leatherarmor = {
  name = 'Leather Armor',
  quadname = 'leatherarmor',
  itemtype = 'leatherarmor',
  isEquipment = true,
  fg = colors.mediumbrown,
  slot = 'body',
  ac = 2
}
itemlist.metalarmor = {
  name = 'Armor',
  quadname = 'metalarmor',
  itemtype = 'metalarmor',
  isEquipment = true,
  fg = colors.gray,
  slot = 'body',
  ac = 4
}
itemlist.cloak = {
  name = 'Cloak',
  quadname = 'cloak',
  itemtype = 'cloak',
  isEquipment = true,
  fg = colors.purple,
  slot = 'body',
  ac = 1
}
return itemlist
