local settings = require 'modules.setup.settings'
local colors = require 'modules.setup.colors'
local utils = require 'modules.setup.utils'
local mapfeaturelist = require 'modules.level.mapfeaturelist'

local defaults = {
  zIndex = 3,
  visible = true,
  open = false,
  blocksMovement = true,
  blocksVision = false,
  name = 'Default',
  quadname = 'unknown'
}
local mapfeature = Class{__includes = {
  require 'modules.tile',
  defaults
}}

function mapfeature:init(x, y, args)
  self.x = x or 1
  self.y = y or 1
  self.drawX = (self.x-1) * settings.tilesize
  self.drawY = (self.y-1) * settings.tilesize

  self.fg = colors.mediumbrown
  self.bg = colors.transparent
  self.w = settings.tilesize
  self.h = settings.tilesize

  utils.copy(self, args or {})

  utils.copy(self, mapfeaturelist[self.mapfeaturetype])

  if self.postInit then self:postInit() end
end

-----------------------------------------------------------
-- Drawing functions
-----------------------------------------------------------
function mapfeature:draw()
  if self.visible then
    local x, y, w, h = self.drawX, self.drawY, self.w, self.h
    lg.setColor(self.bg)
    lg.rectangle('fill', x, y, w, h)
    lg.setColor(self.fg)
    lg.draw(QualeTiles, QualeQuads[self.quadname], x, y)
    lg.setColor(colors.white)
  end
end

function mapfeature:updateVisibility(vis)
  local x,y = self.x, self.y
  if vis[y] and vis[y][x] == 1 then
    self.visible = true
  else
    self.visible = false
  end
end


-----------------------------------------------------------
-- saving
-----------------------------------------------------------
function mapfeature:save()
  return {
    type = 'Mapfeature',
    x = self.x,
    y = self.y,
    args = {
      mapfeaturetype = self.mapfeaturetype
    }
  }
end

return mapfeature
