local colors = require 'modules.setup.colors'
local settings = require 'modules.setup.settings'
local utils = require 'modules.setup.utils'

local mapfeaturelist = {}

mapfeaturelist.generic = {}
-----------------------------------------------------------
-- stairs
-----------------------------------------------------------
mapfeaturelist.stairsup = {
  name = 'Stairs Up',
  quadname = 'stairsup',
  mapfeaturetype = 'stairsup',
  fg = colors.gray,
  bg = colors.black,
  blocksMovement = false,
  blocksVision = false
}

mapfeaturelist.stairsdown = {
  name = 'Stairs Down',
  quadname = 'stairsdown',
  mapfeaturetype = 'stairsdown',
  fg = colors.gray,
  bg = colors.black,
  blocksMovement = false,
  blocksVision = false
}
-----------------------------------------------------------
-- doors
-----------------------------------------------------------
mapfeaturelist.door = {
  name = 'Door',
  quadname = 'doorclosed',
  fg = colors.brown,
  bg = colors.black,
  blocksMovement = true,
  blocksVision = true,
  closeDoor = function(self)
    self.open = false
    self.blocksMovement = true
    self.quadname = 'doorclosed'
  end,
  openDoor = function(self)
    self.open = true
    self.blocksMovement = false
    self.quadname = 'dooropen'
  end,
  save = function(self)
    return {
      type = 'Mapfeature',
      x = self.x,
      y = self.y,
      args = {
        mapfeaturetype = 'door',
        open = self.open,
      }
    }
  end,
  postInit = function(self)
    if self.open then
      self:openDoor()
    end
  end
}

-----------------------------------------------------------
-- flowers
-----------------------------------------------------------
mapfeaturelist.tinyflower = {
  name = 'Tiny Flower',
  quadname = 'tinyflower',
  fg = colors.lightblue,
  blocksMovement = false,
  save = function(self)
    return {
      type = 'Mapfeature',
      x = self.x,
      y = self.y,
      args = {
        mapfeaturetype = 'tinyflower',
        fg = self.fg,
      }
    }
  end,
  postInit = function(self)
    self.fg = table.random({
      colors.lightblue, colors.purple, colors.darkblue, colors.red,
      colors.rust, colors.yellow, colors.white, colors.pink, colors.orange
    })
  end
}

mapfeaturelist.flower = {
  name = 'Flower',
  quadname = 'flower',
  fg = colors.lightblue,
  blocksMovement = false,
  save = function(self)
    return {
      type = 'Mapfeature',
      x = self.x,
      y = self.y,
      args = {
        mapfeaturetype = 'flower',
        fg = self.fg,
      }
    }
  end,
  postInit = function(self)
    self.fg = table.random({
      colors.lightblue, colors.purple, colors.darkblue, colors.red,
      colors.rust, colors.yellow, colors.white, colors.pink, colors.orange      
    })
  end
}

-----------------------------------------------------------
-- other stuff?
-----------------------------------------------------------
mapfeaturelist.pot = {
  name = 'Pot',
  quadname = 'pot',
  fg = colors.mediumbrown,
  blocksMovement = true
}
return mapfeaturelist
