local settings = require 'modules.setup.settings'
local utils = {}

function utils.deScaleXY(px,py)
  local x,y
  x = math.floor(px / settings.scale)
  y = math.floor(py / settings.scale)
  return x,y
end

function utils.checkCollision(x1,y1,w1,h1, x2,y2,w2,h2)
  return x1 < x2+w2 and
         x2 < x1+w1 and
         y1 < y2+h2 and
         y2 < y1+h1
end

function utils.pointInRect(x,y, x2,y2,w,h)
  return utils.checkCollision(x,y,0,0,x2,y2,w,h)
end

function utils.copy(a, b)
  for k,v in pairs(b) do
    a[k] = v
  end
end

function utils.clone(t) -- deep-copy a table
    if type(t) ~= "table" then return t end
    local meta = getmetatable(t)
    local target = {}
    for k, v in pairs(t) do
        if type(v) == "table" then
            target[k] = utils.clone(v)
        else
            target[k] = v
        end
    end
    setmetatable(target, meta)
    return target
end

-- string templating
-- usage is:
-- local qux = utils.template(("${name} is ${value}", {name = "foo", value = "bar"})
-- local baz = "${name} is ${value}" % {name = "foo", value = "bar"}
function utils.template(s, tab)
  return (s:gsub('($%b{})', function(w) return tab[w:sub(3, -2)] or w end))
end
getmetatable("").__mod = utils.template

function utils.roll(dice, sides, modifier)
  if type(dice) == 'table' then
    local t = dice
    return utils.roll(t[1],t[2],t[3])
  end
  local val = 0
  local mod = modifier or 0
  for i=1, dice do
    val = val + love.math.random(1, sides)
  end

  return val + mod
end

function utils.rollTable(t)
  local d,s,m = t[1],t[2],t[3]

  utils.roll(d,s,m)
end

return utils
