local settings = require 'modules.setup.settings'
local colors = require 'modules.setup.colors'
local utils = require 'modules.setup.utils'
local text = require 'modules.ui.text'
local defaults = {
  x = 0,
  y = 0,
  bg = colors.black,
  drawtext = '',
  duration = 4,
  rate = .01,
  count = 1,
  direction = 1,
  zIndex = 20
}

local descriptionText = Class{__includes = {
  text, defaults
}}

function descriptionText:init(args)
  self.font = QualeFont
  -- copy args to self:
  utils.copy(self, args)
  local temp = lg.newText(self.font, self.text)
  self.w, self.h = temp:getDimensions()

  if self.align == 'center' then
    local mod = math.floor(self.w / 2 / settings.tilesize) * settings.tilesize
    self.x = self.x - mod
  end

  self.timer = Timer.every(self.rate, function()
    self:tick()
  end)
end

function descriptionText:draw()
  if self.text ~= nil and self.visible then
    local x, y, w, h = self.x, self.y, self.w, self.h
    -- background color
    if self.bgColor ~= nil then
      lg.setColor(self.bgColor)
      lg.rectangle('fill', x, y, w, h)
    end

    -- text
    lg.setFont(self.font)
    lg.setColor(self.color)
    if self.align and self.limit then
      lg.printf(self.drawtext, x, y, self.limit, self.align)
    else
      lg.print(self.drawtext, x, y)
    end
  end
end

function descriptionText:tick()
  self.drawtext = string.sub(self.text, 1, self.count) .. '_'
  self.count = self.count + 1 * self.direction
  if #self.drawtext == #self.text + 1 then
    self.drawtext = self.text
    Timer.cancel(self.timer)
    Timer.after(self.duration, function()
      self.direction = -1
      self.timer = Timer.every(self.rate, function()
        self:tick()
      end)
    end)
  elseif self.direction == -1 and #self.drawtext == 1 then
    self._remove = true
  end
end

return descriptionText
