local colors = require 'modules.setup.colors'
local settings = require 'modules.setup.settings'
local utils = require 'modules.setup.utils'

local defaults = {
  x = 0,
  y = 0,
  color = colors.red,
  bgColor = colors.transparent,
  text = nil,
  duration = 1,
  align = 'center',
  visible = true,
  zIndex = 20
}

local floatingText = Class{__includes = {
  defaults
}}

function floatingText:init(args)
  self.font = QualeFont

  -- copy args to self:
  utils.copy(self, args)
  local temp = lg.newText(self.font, self.text)
  self.w, self.h = temp:getDimensions()
  self.limit = self.w

  self.x = self.x - self.w / 2

  -- kill after duration
  Timer.after(self.duration, function()
    self._remove = true
  end)
  -- tween position for bounce
  local ty = self.y - settings.tilesize / 2

  Timer.tween(0.2, self, {y=ty}, 'out-back')
end

function floatingText:draw()
  if self.text ~= nil and self.visible then
    local x, y, w, h = self.x, self.y, self.w, self.h
    -- background color
    if self.bgColor ~= nil then
      lg.setColor(self.bgColor)
      lg.rectangle('fill', x, y, w, h)
    end

    -- text
    lg.setFont(self.font)
    lg.setColor(self.color)

    lg.printf(self.text, x, y, self.limit, self.align)

  end
  lg.setColor(colors.white)

end

return floatingText
