local colors = require 'modules.setup.colors'
local settings = require 'modules.setup.settings'
local utils = require 'modules.setup.utils'

local defaults = {
  font = QualeFont,
  fg = colors.white,
  bg = colors.black,
  x = 0,
  y = 0,
  lineHeight = settings.tilesize,
  selection = 0,
  options = {},
  handlers = {}
}

local menu = Class{__includes = {
  defaults
}}

-----------------------------------------------------------
-- Init
-----------------------------------------------------------
function menu:init(options)
  self.options = options or {}
end

-----------------------------------------------------------
-- Update
-----------------------------------------------------------
function menu:update(dt)

end

-----------------------------------------------------------
-- Drawing
-----------------------------------------------------------
function menu:draw()
  -- can be overwritten on a per-instance basis
  self:defaultDraw()
end

function menu:defaultDraw()
  local opts = self.options
  local s = settings.scale
  local x, y = self.x, self.y
  local lh = self.lineHeight
  local selected = self:selected() + 1

  lg.setColor(self.fg)
  if self.name then
    lg.print(self.name, x, y)
    y = y + lh
  end
  for i=1, #opts do
    local str = ''
    if i == selected then
      str = str .. '> ' .. opts[i]
    else
      str = opts[i]
    end

    lg.print(str, x, y)
    y = y + lh
  end
end

-----------------------------------------------------------
-- Actual menu functions
-----------------------------------------------------------
function menu:selected()
  return self.selection
end

function menu:onSelect(func)
  self.handlers['select'] = func
end

function menu:select()
  local option = self.options[self.selection + 1]
  if self.handlers['select'] then
    self.handlers['select'](option)
  end
end

function menu:decrement()
  self.selection = (self.selection - 1) % #self.options
end

function menu:increment()
  self.selection = (self.selection + 1) % #self.options
end

return menu
