local colors = require 'modules.setup.colors'
local settings = require 'modules.setup.settings'
local utils = require 'modules.setup.utils'

local defaults = {
  isActive = false,
}
local gamestatemenu = Class {__includes = {
  require 'modules.ui.menu',
  defaults
}}

-----------------------------------------------------------
-- Init
-----------------------------------------------------------
function gamestatemenu:init(parent)
  self.parent = parent
  self.x = 0
  self.y = settings.tilesize
  self.bg = colors.darkgreen
  self.options = {
    'Stats',
    'Equipment',
    'Inventory',
    'Save and Quit',
    'Quit Without Saving',
    'Cancel',
  }

  self.w = QualeFont:getWidth('Quit Without Saving') + settings.tilesize
  self.h = #self.options * settings.tilesize

  self:onSelect(function(option)
    local bindings = {
      ['Stats'] = function()
        self.parent.currentmenu = self.parent.statsmenu
        self.parent.statsmenu:activate()
      end,
      ['Equipment'] = function()
        self.parent.currentmenu = self.parent.equipmentmenu
        self.parent.equipmentmenu:activate()
      end,
      ['Inventory'] = function()
        self.parent.currentmenu = self.parent.inventorymenu
        self.parent.inventorymenu:activate()
      end,
      ['Cancel'] = function() self:deactivate() end,
      ['Save and Quit'] = function()
        self.parent:save()
        Gamestate.switch(MainMenu)
      end,
      ['Quit Without Saving'] = function() le.quit() end
    }
    local action = bindings[option]
    if action then action() end
  end)
end

-----------------------------------------------------------
-- Activation
-----------------------------------------------------------
function gamestatemenu:activate()
  self.selection = 0
  self.isActive = true
end

function gamestatemenu:deactivate()
  self.isActive = false
  self.parent.currentmenu = nil
end

function gamestatemenu:toggle()
  if self.isActive then
    self:deactivate()
  else
    self:activate()
  end
end
-----------------------------------------------------------
-- Update
-----------------------------------------------------------
function gamestatemenu:update(dt)

end

-----------------------------------------------------------
-- Drawing
-----------------------------------------------------------
function gamestatemenu:draw()
  -- can be overwritten on a per-instance basis
  if self.isActive then
    lg.setColor(self.bg)
    lg.rectangle('fill', self.x, self.y, self.w, self.h)
    lg.setColor(self.fg)
    self:defaultDraw()
  end
end

return gamestatemenu
