local colors = require 'modules.setup.colors'
local settings = require 'modules.setup.settings'
local utils = require 'modules.setup.utils'
local itemlist = require 'modules.items.itemlist'
local menu = require 'modules.ui.menu'

local defaults = {
  isActive = true,
}
local inventorysubmenu = Class {__includes = {
  menu,
  defaults
}}

-----------------------------------------------------------
-- Init
-----------------------------------------------------------
function inventorysubmenu:init(parent, opts)
  self.parent = parent
  self.x = 60
  self.y = settings.tilesize
  self.bg = colors.darkgreen

  self.options =  opts or {'Use', 'Info', 'Equip', 'Toss', 'Cancel'}

  self:onSelect(function(option)
    local bindings = {
      ['Use'] = function() self.parent:handleAction('use') end,
      ['Equip'] = function() self.parent:handleAction('equip') end,
      ['Toss'] = function() self.parent:handleAction('toss') end,
      ['Info'] = function() self.parent:handleAction('info') end,
      ['Cancel'] = function() self:deactivate() end,
    }
    local action = bindings[option]
    if type(action) == 'function' then
      action()
    else
      --TODO
    end
  end)
  self:updateDimensions()
  self:updatePosition()
end

-----------------------------------------------------------
-- Activation
-----------------------------------------------------------
function inventorysubmenu:deactivate()
  self.parent:closeSubmenu()
end

function inventorysubmenu:useItem()
  local selfinv = self.inventory
  local selected = self:selected() + 1
  self.parent.player:useItem(selected)
  self:onOpen()
end

function inventorysubmenu:updateDimensions()
  self.h = #self.options * settings.tilesize
  local w = 0
  for i=1,#self.options do
    local str = self.options[i]
    local temp = QualeFont:getWidth(str)
    w = math.max(w, temp)
  end
  self.w = w + settings.tilesize
end

function inventorysubmenu:updatePosition()
  local w,h = self.w, self.h
  local pw = self.parent.w
  self.x = pw
  while self.x + self.w > settings.pxWidth do
    self.x = self.x - settings.tilesize
  end
end

-----------------------------------------------------------
-- Update
-----------------------------------------------------------
function inventorysubmenu:update(dt)

end

-----------------------------------------------------------
-- Drawing
-----------------------------------------------------------
function inventorysubmenu:draw()
  local opts = self.options
  local x, y = self.x, self.y
  local lh = settings.tilesize
  local selected = self:selected() + 1

  if self.isActive then
    lg.setColor(self.bg)
    lg.rectangle('fill', self.x, self.y, self.w, self.h)
    lg.setColor(self.fg)
    self:defaultDraw()
  end
end


-----------------------------------------------------------
-- menu functions
-----------------------------------------------------------


return inventorysubmenu
