local colors = require 'modules.setup.colors'
local settings = require 'modules.setup.settings'
local utils = require 'modules.setup.utils'

local optionsmenu = Class {__includes = {
  require 'modules.ui.menu',
  defaults
}}

-----------------------------------------------------------
-- Init
-----------------------------------------------------------
function optionsmenu:init()
  self.name = 'OPTIONS'

  self.options = {
    {text='Fancy Screen Effects', boolean = 'screenEffects'},
    {text='Return to Menu'}
  }
  self:onSelect(function(option)
    local bindings = {
      ['Fancy Screen Effects'] = function()
        USERSETTINGS.screenEffects = not USERSETTINGS.screenEffects
      end,
      ['Return to Menu'] = function()
        Gamestate.switch(MainMenu)
      end
    }
    local action = bindings[option]
    if action then action() end
    self:save()
  end)
end

-----------------------------------------------------------
-- Update
-----------------------------------------------------------
function optionsmenu:update(dt)

end

function optionsmenu:select()
  local option = self.options[self.selection + 1].text
  if self.handlers['select'] then
    self.handlers['select'](option)
  end
end
-----------------------------------------------------------
-- Drawing
-----------------------------------------------------------
function optionsmenu:draw()
  local opts = self.options
  local s = settings.scale
  local x, y = self.x, self.y
  local lh = self.lineHeight
  local selected = self:selected() + 1

  lg.setColor(self.fg)
  if self.name then
    lg.print(self.name, x, y)
    y = y + lh
  end
  for i=1, #opts do
    local opt = opts[i]
    local str = ''
    if i == selected then
      str = str .. '> ' .. opt.text
      if opt.boolean ~= nil then
        local status = USERSETTINGS[opt.boolean]
        if status == true then
          str = str .. ' [ON]'
        else
          str = str .. ' [OFF]'
        end
      end
    else
      str = opt.text
    end

    lg.print(str, x, y)
    y = y + lh
  end

end

function optionsmenu:save()
  lf.write('settings.json', JSON.encode(USERSETTINGS))
end

return optionsmenu
