local colors = require 'modules.setup.colors'
local settings = require 'modules.setup.settings'
local utils = require 'modules.setup.utils'
local itemlist = require 'modules.items.itemlist'
local menu = require 'modules.ui.menu'

local defaults = {
  isActive = false,
}
local statsmenu = Class {__includes = {
  menu,
  defaults
}}

-----------------------------------------------------------
-- Init
-----------------------------------------------------------
function statsmenu:init(parent)
  self.parent = parent
  self.x = 0
  self.y = settings.tilesize
  self.bg = colors.darkgreen
  self.options = {
    'Cancel',
  }
  self:onSelect(function(option)
    local bindings = {
      ['Cancel'] = function() self:deactivate() end,
    }
    local action = bindings[option]
    if type(action) == 'function' then
      action()
    end
  end)
end

-----------------------------------------------------------
-- Activation
-----------------------------------------------------------
function statsmenu:activate()
  self:onOpen()
  self.selection = 0
  self.isActive = true
  self.submenu = nil
end

function statsmenu:deactivate()
  local parent = self.parent
  self.isActive = false
  parent.menu.isActive = true
  parent.currentmenu = parent.menu
end

function statsmenu:toggle()
  if self.isActive then
    self:deactivate()
  else
    self:activate()
  end
end

function statsmenu:onOpen()
  local player = self.parent.player
  player:calculateStats()
  self.w, self.h = 0, 0
  self.text = [[STATS
HP: ${hp}/${maxhp}
STR: ${str}
DEX: ${dex}
MIND: ${mind}
Armor: ${ac}
XP: ${xp}]] % player
  self:updateDimensions()
end

function statsmenu:updateDimensions()
  local text = self.text .. '\nCancel'
  local w, wt = QualeFont:getWrap(text, settings.pxWidth)
  self.h = #wt * settings.tilesize
  self.w = w + settings.tilesize
end

-----------------------------------------------------------
-- Update
-----------------------------------------------------------
function statsmenu:update(dt)

end

-----------------------------------------------------------
-- Drawing
-----------------------------------------------------------
function statsmenu:draw()
  if self.isActive then
    self:drawBackground()
    lg.setColor(colors.white)
    lg.print(self.text .. '\n> Cancel', self.x, self.y)
  end
end

function statsmenu:drawBackground()
  local x, y, w, h = self.x, self.y, self.w, self.h
  lg.setColor(self.bg)
  lg.rectangle('fill', x, y, w, h)
end

-----------------------------------------------------------
-- menu functions
-----------------------------------------------------------
function statsmenu:select()
  if self.submenu ~= nil then
    self.submenu:select()
  else
    local option = self.options[self.selection + 1]
    if self.handlers['select'] then
      self.handlers['select'](option)
    end
  end
end


return statsmenu
