local settings = require 'modules.setup.settings'
local colors = require 'modules.setup.colors'
local utils = require 'modules.setup.utils'
local defaults = {
  x = 0,
  y = 0,
  color = colors.white,
  bgColor = nil,
  lines = {},
  visible = true,
  wrapWidth = settings.pxWidth / settings.scale - 16,
  maxLines = 3,
  padding = 8,
  font = QualeFont
}

local messageLog = Class{__includes = {
  defaults
}}

function messageLog:init(args)
  utils.copy(self, args or {})

  local temp = lg.newText(self.font, 'Temp')
  local w, h = temp:getDimensions()
  self.lineHeight = h
  self.h = self.lineHeight * self.maxLines
  self.w = self.wrapWidth + self.padding * 2

  local s = self

  self.signal = Signal.register('message', function(line)
    s:addLine(line)
  end)
end


-- Drawing
function messageLog:draw()
  local lines = self.lines
  if #lines > 0 then
    local maxLines = self.maxLines
    local x, y = self.x + self.padding, self.y

    for i=1,#lines do
      if i > maxLines then break end
      self:drawLine(lines[i], x, y)
      y = y + self.lineHeight
    end
  end
end

function messageLog:drawLine(line, x, y)
  lg.setColor(colors.white)
  lg.print(line, x, y)
end

-- adding lines
function messageLog:addLine(line)
  table.insert(self.lines, 1, line)
end

return messageLog
