local settings = require 'modules.setup.settings'
local colors = require 'modules.setup.colors'
local utils = require 'modules.setup.utils'
local defaults = {
  x = 0,
  y = settings.pxHeight - settings.tilesize,
  w = settings.pxWidth,
  h = settings.tilesize,
  fg = colors.white,
  bg = colors.black,
  text = '',
  visible = true,
  padding = 8,
  font = QualeFont,
  count = 0,
  stringlength = 0,
  messageSpeed = 2,
  align = 'left'
}

local messageLog = Class{__includes = {
  defaults
}}

function messageLog:init(args)
  self.maxWidth = settings.pxWidth - self.padding * 2
  utils.copy(self, args or {})

  local s = self
  self.signal = Signal.register('message', function(line)
    s:addLine(line)
  end)
end

-- update
function messageLog:update(dt)
  if self.count < self.stringlength then
    self.count = self.count + self.messageSpeed
  end
end


-- Drawing
function messageLog:draw()
  local x,y,w,h = self.x, self.y, self.w, self.h
  lg.setColor(self.bg)
  lg.rectangle('fill', x, y, w, h)
  lg.setColor(self.fg)
  lg.setFont(self.font)
  local str = string.sub(self.text, 1, self.count)
  lg.printf(str, x + self.padding, y, self.maxWidth, self.align)
end

-- adding lines
function messageLog:addLine(line)
  self.text = line
  self.stringlength = string.len(line)
  self.count = 0
  local width, wrappedtext = self.font:getWrap( line, self.maxWidth )
  self.w = width + self.padding * 2
  self.h = #wrappedtext * settings.tilesize
  self.y = settings.pxHeight - self.h
end

return messageLog
