local settings = require 'modules.setup.settings'
local colors = require 'modules.setup.colors'
local titlemenu = require 'modules.ui.menus.titlemenu'

MainMenu = {}
-----------------------------------------------------------
-- Init functions
-----------------------------------------------------------
function MainMenu:init()
  self.smallCanvas = lg.newCanvas(settings.pxWidth, settings.pxHeight)
  self.text = [[
CONTROLS

[WASD] or [ARROWS] ....... Move
[ESC] .................... Menu
[SPACE] ......... Pick up items
                 or close doors
[ENTER] .......... Confirm menu
                     selections


]]
end

function MainMenu:enter()
  local width, wrappedtext = QualeFont:getWrap(self.text, settings.pxWidth)
  local strwidth = QualeFont:getWidth('> New Game')
  local x = math.floor((settings.pxWidth - strwidth)/ 2)
  local y = #wrappedtext * settings.tilesize
  self.menu = titlemenu()
  self.menu.x = x
  self.menu.y = y
  if lf.exists(settings.savefilename) then
    table.insert(self.menu.options, 1, 'Continue')
  end
  self.menu.selection = 0
end

-----------------------------------------------------------
-- Update functions
-----------------------------------------------------------
function MainMenu:update(dt)

end

-----------------------------------------------------------
-- Draw functions
-----------------------------------------------------------
function MainMenu:draw()
  self:preDraw()
  lg.setColor(colors.white)
  lg.printf(self.text, 0, 0, settings.pxWidth, 'left')
  self.menu:draw()
  self:postDraw()
end

function MainMenu:preDraw()
  lg.setCanvas(self.smallCanvas)
  lg.clear(colors.black)
  lg.setColor({255,255,255})
  lg.push()
end

function MainMenu:postDraw()
  lg.pop()
  lg.setCanvas()
  lg.draw(self.smallCanvas, 0, 0, 0, GscaleX, GscaleY)
end

-----------------------------------------------------------
-- Input functions
-----------------------------------------------------------

function MainMenu:keypressed(key, code)
  local menu = self.menu

  local keys = {
    w =           'decrement',
    up =          'decrement',
    s =           'increment',
    down =        'increment',
    ['return'] =  'select'
  }

  local bindings = {
    decrement = function() menu:decrement() end,
    increment = function() menu:increment() end,
    select = function() menu:select() end
  }

  local func = keys[key]
  local action = bindings[func]
  if action then action() end
end
